var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import * as React from 'react';
import { isSameDay, isSameMonth } from 'date-fns';
import { useNavigation, useProps } from '../../hooks';
import { UIElement } from '../../types';
import { getModifiers } from './utils/getModifiers';
export function Day(props) {
    var el = React.useRef(null);
    var dayPickerProps = useProps();
    var labels = dayPickerProps.labels, formatters = dayPickerProps.formatters, locale = dayPickerProps.locale, showOutsideDays = dayPickerProps.showOutsideDays;
    var _a = useNavigation(), currentMonth = _a.currentMonth, focusedDay = _a.focusedDay;
    var displayMonth = props.displayMonth, day = props.day;
    var formatDay = formatters.formatDay;
    // Do not return anything if the day is not in the range
    var modifiers = getModifiers(day, displayMonth, dayPickerProps);
    React.useEffect(function () {
        var _a;
        if (!focusedDay)
            return;
        if (isSameDay(focusedDay, day))
            (_a = el === null || el === void 0 ? void 0 : el.current) === null || _a === void 0 ? void 0 : _a.focus();
    }, [focusedDay]);
    if (modifiers.hidden)
        return null;
    if (modifiers.outside && !showOutsideDays)
        return null;
    var ariaLabel = labels.dayLabel(day, modifiers, { locale: locale });
    var ariaPressed = modifiers.interactive ? modifiers.selected : undefined;
    var disabled = modifiers.disabled;
    // #region TabIndex
    var tabIndex = !modifiers.interactive ? undefined : -1;
    if (modifiers.interactive) {
        if ((focusedDay && isSameDay(day, focusedDay)) ||
            (isSameMonth(day, currentMonth) && day.getDate() === 1)) {
            tabIndex = 0;
        }
    }
    // #endregion
    // #region EventHandlers
    var onDayBlur = dayPickerProps.onDayBlur, onDayClick = dayPickerProps.onDayClick, onDayFocus = dayPickerProps.onDayFocus, onDayKeyDown = dayPickerProps.onDayKeyDown;
    var handleClick = function (e) {
        onDayClick(day, modifiers, e);
    };
    var handleFocus = function (e) {
        onDayFocus(day, modifiers, e);
    };
    var handleBlur = function (e) {
        onDayBlur(day, modifiers, e);
    };
    var handleKeyDown = function (e) {
        onDayKeyDown(day, modifiers, e);
    };
    var handleKeyUp = function (e) {
        var _a;
        (_a = props.onDayKeyUp) === null || _a === void 0 ? void 0 : _a.call(props, day, modifiers, e);
    };
    var handleMouseEnter = function (e) {
        var _a;
        (_a = props.onDayMouseEnter) === null || _a === void 0 ? void 0 : _a.call(props, day, modifiers, e);
    };
    var handleMouseLeave = function (e) {
        var _a;
        (_a = props.onDayMouseLeave) === null || _a === void 0 ? void 0 : _a.call(props, day, modifiers, e);
    };
    var handleTouchCancel = function (e) {
        var _a;
        (_a = props.onDayTouchCancel) === null || _a === void 0 ? void 0 : _a.call(props, day, modifiers, e);
    };
    var handleTouchEnd = function (e) {
        var _a;
        (_a = props.onDayTouchEnd) === null || _a === void 0 ? void 0 : _a.call(props, day, modifiers, e);
    };
    var handleTouchMove = function (e) {
        var _a;
        (_a = props.onDayTouchMove) === null || _a === void 0 ? void 0 : _a.call(props, day, modifiers, e);
    };
    var handleTouchStart = function (e) {
        var _a;
        (_a = props.onDayTouchStart) === null || _a === void 0 ? void 0 : _a.call(props, day, modifiers, e);
    };
    // #endregion
    // #region ClassNames
    var classNames = dayPickerProps.classNames, modifiersClassNames = dayPickerProps.modifiersClassNames, modifierPrefix = dayPickerProps.modifierPrefix;
    var buttonClassNames = [classNames[UIElement.Day]];
    Object.keys(modifiers)
        .filter(function (modifier) { return Boolean(modifiers[modifier]); })
        .forEach(function (modifier) {
        if (modifiersClassNames === null || modifiersClassNames === void 0 ? void 0 : modifiersClassNames[modifier]) {
            // Use class name coming from props
            buttonClassNames.push(modifiersClassNames[modifier]);
        }
        else {
            // Create a class name with the prefix
            buttonClassNames.push("" + modifierPrefix + modifier);
        }
    });
    // #endregion
    // #region Styles
    var styles = dayPickerProps.styles, modifiersStyles = dayPickerProps.modifiersStyles;
    var style = __assign({}, styles === null || styles === void 0 ? void 0 : styles[UIElement.Day]);
    if (styles) {
        Object.keys(modifiers).forEach(function (modifier) {
            style = __assign(__assign({}, style), styles[modifier]);
        });
    }
    if (modifiersStyles) {
        Object.keys(modifiers).forEach(function (modifier) {
            style = __assign(__assign({}, style), modifiersStyles[modifier]);
        });
    }
    // #endregion
    var Component = modifiers.interactive ? 'button' : 'span';
    return (React.createElement(Component, { ref: el, "aria-label": ariaLabel, "aria-pressed": ariaPressed, disabled: disabled, style: style, className: buttonClassNames.join(' '), tabIndex: tabIndex, onClick: handleClick, onFocus: handleFocus, onBlur: handleBlur, onKeyDown: handleKeyDown, onKeyUp: handleKeyUp, onMouseEnter: handleMouseEnter, onMouseLeave: handleMouseLeave, onTouchCancel: handleTouchCancel, onTouchEnd: handleTouchEnd, onTouchMove: handleTouchMove, onTouchStart: handleTouchStart }, formatDay(day, { locale: locale })));
}
//# sourceMappingURL=Day.js.map