import { differenceInCalendarDays, isSameDay } from 'date-fns';
function matchDate(day, matcher) {
    if (!(matcher instanceof Date))
        return false;
    return isSameDay(day, matcher);
}
function matchBeforeAndAfter(day, matcher) {
    if (!('before' in matcher) || !('after' in matcher))
        return false;
    return (differenceInCalendarDays(day, matcher.before) < 0 &&
        differenceInCalendarDays(day, matcher.after) > 0);
}
function matchBefore(day, matcher) {
    if (!('before' in matcher) || 'after' in matcher)
        return false;
    return differenceInCalendarDays(day, matcher.before) < 0;
}
function matchAfter(day, matcher) {
    if (!('after' in matcher) || 'before' in matcher)
        return false;
    return differenceInCalendarDays(day, matcher.after) > 0;
}
function matchRange(day, matcher) {
    var _a;
    if (!('from' in matcher))
        return false;
    if (!matcher.from)
        return false;
    var from = matcher.from, to = matcher.to;
    // Matches { from: <Date> }
    if (!to && from && isSameDay(from, day))
        return true;
    if (!to)
        return false;
    // Invert the case where "to" is before "from"
    if (matcher.to && differenceInCalendarDays(matcher.to, matcher.from) < 0) {
        _a = [matcher.to, matcher.from], from = _a[0], to = _a[1];
    }
    return (differenceInCalendarDays(day, from) >= 0 &&
        differenceInCalendarDays(to, day) >= 0);
}
function matchDaysOfWeek(day, matcher) {
    if (!('daysOfWeek' in matcher))
        return false;
    return matcher.daysOfWeek.includes(day.getDay());
}
function matchFunction(day, matcher, currentMonth, props) {
    if (!(matcher instanceof Function))
        return false;
    return matcher(day, currentMonth, props);
}
export function matchDay(day, matcher, currentMonth, props) {
    if (!matcher)
        return false;
    var matchers;
    if (Array.isArray(matcher)) {
        matchers = matcher;
    }
    else {
        matchers = [matcher];
    }
    return matchers.some(function (dayMatcher) {
        if (!dayMatcher)
            return false;
        return (
        // Precedence shouldn't be important here
        matchDate(day, dayMatcher) ||
            matchBeforeAndAfter(day, dayMatcher) ||
            matchBefore(day, dayMatcher) ||
            matchAfter(day, dayMatcher) ||
            matchRange(day, dayMatcher) ||
            matchDaysOfWeek(day, dayMatcher) ||
            matchFunction(day, dayMatcher, currentMonth, props));
    });
}
//# sourceMappingURL=matchModifier.js.map