var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React, { useState } from 'react';
import { addDays, addWeeks, isAfter, isBefore, isSameMonth, startOfMonth } from 'date-fns';
import { PropsContext, Root } from '../../components';
import { useSelection } from '../../hooks/useSelection';
import { KeyCode } from '../../types';
import { defaultClassNames, defaultComponents, defaultLabels, defaultModifiers } from './defaults';
import { defaultFormatters } from './defaults/defaultFormatters';
import { NavigationContext } from './NavigationContext';
import { defaultPropsValues as defaults } from './PropsContext';
import { getMonthsToRender } from './utils/getMonthsToRender';
import { getNavMonths } from './utils/getNavMonths';
/**
 * Render a date picker component.
 *
 * **Example**
 *
 * ```jsx
 * function Example() {
 *   const [selected, setSelected] = useState();
 *
 *   const handleDayClick = (day, { selected }) => {
 *     if (!selected) setSelected(day);
 *     else setSelected();
 *   };
 *
 *   return <DayPicker selected={selected} onDayClick={handleDayClick} />;
 * }
 * ```
 */
export function DayPicker(props) {
    var _a;
    //#region Default values
    var today = (_a = props.today) !== null && _a !== void 0 ? _a : defaults.today;
    var locale = props.locale || defaults.locale;
    var numberOfMonths = props.numberOfMonths || defaults.numberOfMonths;
    var showOutsideDays = props.showOutsideDays || props.fixedWeeks;
    var type = 'selected' in props ? 'uncontrolled' : props.type || defaults.type;
    // Give precedence to `fromYear` and `fromMonth`
    var fromDate = props.fromDate;
    if (props.fromMonth)
        fromDate = startOfMonth(props.fromMonth);
    else if (props.fromYear)
        fromDate = new Date(props.fromYear, 0, 1);
    // Give precedence to `toYear` and `toMonth`
    var toDate = props.toDate;
    if (props.toMonth)
        toDate = startOfMonth(props.toMonth);
    else if (props.toYear)
        toDate = new Date(props.toYear, 11, 31);
    var captionLayout = props.captionLayout || defaults.captionLayout;
    if (captionLayout === 'dropdown' &&
        ((!fromDate && !toDate) || numberOfMonths > 1)) {
        captionLayout = 'buttons';
    }
    //#endregion
    //#region Current month
    // As default, month is controlled by DayPicker, where the initial value is
    // `defaultMonth`. If props.month is passed, then the parent component must
    // control the month via `onMonthChange`.
    var _b = useState(!('month' in props)), isMonthControlled = _b[0], setIsMonthControlled = _b[1];
    var _c = useState(props.defaultMonth ? startOfMonth(props.defaultMonth) : undefined), controlledMonth = _c[0], setControlledMonth = _c[1];
    React.useEffect(function () {
        setIsMonthControlled(!('month' in props));
    }, [props.defaultMonth]);
    var currentMonth = controlledMonth || props.month || startOfMonth(today);
    var displayMonths = getMonthsToRender(currentMonth, numberOfMonths, {
        toDate: toDate,
        fromDate: fromDate,
        reverseMonths: props.reverseMonths
    });
    //#endregion
    //#region Controlled selection
    // As default, days selection is controlled by DayPicker – where the initial
    // value comes from `defaultSelected`. If `props.selected` is passed, then the
    // parent component must control the selection via `onDayClick`.
    var defaultSelected = props.defaultSelected, onSelect = props.onSelect, required = props.required;
    var _d = useState(type !== 'uncontrolled'), isSelectionControlled = _d[0], setIsSelectionControlled = _d[1];
    var _e = useSelection(defaultSelected, type, onSelect, { required: required }), controlledSelected = _e[0], setControlledSelected = _e[1], selectionModifiers = _e[2];
    React.useEffect(function () {
        setIsSelectionControlled(type !== 'uncontrolled');
    }, [type]);
    if (!isSelectionControlled)
        type === 'uncontrolled';
    //#endregion
    //#region Focused day
    var _f = useState(), focusedDay = _f[0], setFocusedDay = _f[1];
    //#endregion
    //#region From/to date
    //#endregion
    //#region events
    var onMonthChange = function (newMonth, e) {
        var _a;
        // Do nothing if outside of range
        if (toDate && isAfter(newMonth, startOfMonth(toDate)))
            return;
        if (fromDate && isBefore(newMonth, startOfMonth(fromDate)))
            return;
        if (isMonthControlled)
            setControlledMonth(newMonth);
        (_a = props.onMonthChange) === null || _a === void 0 ? void 0 : _a.call(props, newMonth, e);
    };
    var onDayFocus = function (day, modifiers, e) {
        var _a;
        var sameMonth = isSameMonth(day, currentMonth);
        if (!sameMonth && props.disableNavigation)
            return;
        if (!sameMonth)
            onMonthChange(startOfMonth(day), e);
        setFocusedDay(day);
        (_a = props.onDayFocus) === null || _a === void 0 ? void 0 : _a.call(props, day, modifiers, e);
    };
    var onDayBlur = function (day, modifiers, e) {
        var _a;
        setFocusedDay(undefined);
        (_a = props.onDayBlur) === null || _a === void 0 ? void 0 : _a.call(props, day, modifiers, e);
    };
    var onDayClick = function (day, modifiers, e) {
        var _a;
        (_a = props.onDayClick) === null || _a === void 0 ? void 0 : _a.call(props, day, modifiers, e);
        if (isSelectionControlled)
            setControlledSelected(day, modifiers, e);
    };
    var onDayKeyDown = function (day, modifiers, e) {
        var _a;
        switch (e.code) {
            case KeyCode.ArrowLeft: {
                e.preventDefault();
                e.stopPropagation();
                var nextDay = addDays(day, -1);
                onDayFocus === null || onDayFocus === void 0 ? void 0 : onDayFocus(nextDay, modifiers, e);
                break;
            }
            case KeyCode.ArrowRight: {
                e.preventDefault();
                e.stopPropagation();
                var nextDay = addDays(day, 1);
                onDayFocus === null || onDayFocus === void 0 ? void 0 : onDayFocus(nextDay, modifiers, e);
                return;
            }
            case KeyCode.ArrowUp: {
                e.preventDefault();
                e.stopPropagation();
                var nextDay = addWeeks(day, -1);
                onDayFocus === null || onDayFocus === void 0 ? void 0 : onDayFocus(nextDay, modifiers, e);
                break;
            }
            case KeyCode.ArrowDown: {
                e.preventDefault();
                e.stopPropagation();
                var nextDay = addWeeks(day, 1);
                onDayFocus === null || onDayFocus === void 0 ? void 0 : onDayFocus(nextDay, modifiers, e);
                break;
            }
        }
        (_a = props.onDayKeyDown) === null || _a === void 0 ? void 0 : _a.call(props, day, modifiers, e);
    };
    //#endregion
    var selected = isSelectionControlled ? controlledSelected : props.selected;
    var propsValues = __assign(__assign({}, props), { captionLayout: captionLayout, classNames: __assign(__assign({}, defaultClassNames), props.classNames), components: __assign(__assign({}, defaultComponents), props.components), formatters: __assign(__assign({}, defaultFormatters), props.formatters), labels: __assign(__assign({}, defaultLabels), props.labels), fromDate: fromDate,
        toDate: toDate,
        locale: locale, modifierPrefix: props.modifierPrefix || defaults.modifierPrefix, modifiers: __assign(__assign(__assign({}, defaultModifiers), selectionModifiers), props.modifiers), numberOfMonths: numberOfMonths,
        onDayBlur: onDayBlur,
        onDayClick: onDayClick,
        onDayFocus: onDayFocus,
        onDayKeyDown: onDayKeyDown,
        onMonthChange: onMonthChange, originalProps: props, selected: selected,
        showOutsideDays: showOutsideDays,
        today: today,
        type: type });
    var _g = getNavMonths(currentMonth, {
        fromDate: fromDate,
        toDate: toDate,
        pagedNavigation: props.pagedNavigation,
        numberOfMonths: numberOfMonths,
        disableNavigation: props.disableNavigation
    }), prevMonth = _g[0], nextMonth = _g[1];
    var navigationValues = {
        nextMonth: nextMonth,
        prevMonth: prevMonth,
        currentMonth: currentMonth,
        displayMonths: displayMonths,
        focusedDay: focusedDay
    };
    return (React.createElement(PropsContext.Provider, { value: propsValues },
        React.createElement(NavigationContext.Provider, { value: navigationValues },
            React.createElement(Root, null))));
}
//# sourceMappingURL=DayPicker.js.map