import React from 'react';
import { CaptionLayout, ClassNames, Components, DayClickEventHandler, DayFocusEventHandler, DayKeyboardEventHandler, Formatters, Labels, ModifiersClassNames, ModifiersMatchers, MonthChangeEventHandler } from '../../types';
import { DayPickerProps } from './DayPickerProps';
/**
 * Represent the value of a [[PropsContext]].
 */
export interface PropsValues extends Omit<DayPickerProps, 'className' | 'style' | 'month' | 'fromMonth' | 'toMonth' | 'fromYear' | 'toYear'> {
    captionLayout: CaptionLayout;
    classNames: ClassNames;
    components: Required<Components>;
    formatters: Required<Formatters>;
    labels: Required<Labels>;
    locale: Locale;
    modifierPrefix: string;
    modifiers: ModifiersMatchers;
    modifiersClassNames?: ModifiersClassNames;
    numberOfMonths: number;
    dir?: string;
    /**
     * Will set the current month if DayPicker is in controlled mode. Calls the
     * original `onMonthChange`.
     *
     * This event handler will do nothing if the passed month is outside the
     * allowed months.
     */
    onMonthChange: MonthChangeEventHandler;
    /**
     * Handle focus behavior. Calls the original `onDayBlur` passed from props.
     */
    onDayBlur: DayFocusEventHandler;
    /**
     * Handle click behavior. Calls the original `onDayClick` passed from props.
     */
    onDayClick: DayClickEventHandler;
    /**
     * Handle focus behavior. Calls the original `onDayFocus` passed from props.
     */
    onDayFocus: DayFocusEventHandler;
    /**
     * Handle keyboard navigation. Calls the original `onDayKeyDown` passed from props.
     */
    onDayKeyDown: DayKeyboardEventHandler;
    /**
     * A reference to the original props passed to the component. Useful for
     * inspecting in internal components.
     */
    originalProps: DayPickerProps;
    /**
     * The today’s date used in the calendar. If not overridden from props, is the
     * current date.
     */
    today: Date;
}
export declare const defaultPropsValues: PropsValues;
/**
 * Context to consume DayPicker original props (with defaults) between
 * components.
 */
export declare const PropsContext: React.Context<PropsValues>;
