import { isAfter, isBefore, isSameDay } from 'date-fns';
/**
 * Add a day to an existing range.
 *
 * The returned range takes in account the `undefined` values and if the added
 * day is already present in the range.
 */
export function addToRange(day, range, required) {
    if (required === void 0) { required = false; }
    var _a = range || {}, from = _a.from, to = _a.to;
    if (!from) {
        return { from: day };
    }
    if (!required && !to && isSameDay(from, day)) {
        return undefined;
    }
    if (!to && isBefore(day, from)) {
        return { from: day, to: from };
    }
    if (!to) {
        return { from: from, to: day };
    }
    if (isSameDay(to, day)) {
        return { from: to };
    }
    if (isAfter(from, day)) {
        return { from: day, to: to };
    }
    return { from: from, to: day };
}
//# sourceMappingURL=addToRange.js.map