import { useEffect } from 'react';
import { useMultipleSelection } from '../useMultipleSelection/useMultipleSelection';
import { useRangeSelection } from '../useRangeSelection';
import { useSingleSelection } from '../useSingleSelection/useSingleSelection';
export function useSelection(initialSelection, type, onSelect, options) {
    if (type === void 0) { type = 'single'; }
    if (options === void 0) { options = { required: false }; }
    var initialRange;
    var initialMultiple;
    var initialSingle;
    switch (type) {
        case 'range':
            initialRange = initialSelection;
            break;
        case 'multiple':
            initialMultiple = initialSelection;
            break;
        case 'single':
        default:
            initialSingle = initialSelection;
    }
    var _a = useRangeSelection(initialRange, onSelect, options), range = _a[0], setRange = _a[1], resetRange = _a[2];
    var _b = useMultipleSelection(initialMultiple, onSelect, options), multiple = _b[0], setMultiple = _b[1], resetMultiple = _b[2];
    var _c = useSingleSelection(initialSingle, onSelect, options), single = _c[0], setSingle = _c[1], resetSingle = _c[2];
    var reset = function () {
        resetRange();
        resetMultiple();
        resetSingle();
    };
    useEffect(reset, [type, options.required]);
    var modifiers = {};
    switch (type) {
        case 'range':
            if (range && range.from) {
                modifiers.from = range.from;
            }
            if (range && range.to) {
                modifiers.to = range.to;
            }
            if (range && range.to && range.from) {
                modifiers.between = {
                    after: range.from,
                    before: range.to
                };
            }
            return [range, setRange, modifiers, resetRange];
        case 'multiple':
            return [multiple, setMultiple, modifiers, resetMultiple];
        case 'single':
        default:
            return [single, setSingle, modifiers, resetSingle];
    }
}
//# sourceMappingURL=useSelection.js.map